Enum static_analyser::errors::ErrorKind []

pub enum ErrorKind {
    Msg(String),
    Io(Error),
    Utf8(Utf8Error),
    FloatParsing(ParseFloatError),
    IntParsing(ParseIntError),
    UnexpectedEOF,
    UnknownCharacter(char),
    MessageWithLocation(usize, &'static str),
    // some variants omitted
}

The kind of an error.

Variants

A convenient variant for String.

Wrapper around a std::io::Error

An error parsing data as UTF-8

A float parsing error

An integer parsing error

Got to the end of the input stream but was expecting more.

Reached an unknown character while lexing.

A message which corresponds to some location in the source code.

Methods

impl ErrorKind

A string describing the error kind.