Struct static_analyser::Driver [] [src]

pub struct Driver { /* fields omitted */ }

The driver is in charge of orchestrating the whole analysis process and making sure all the bits and pieces integrate nicely.

Methods

impl Driver
[src]

Create a new driver.

Get access to the driver's CodeMap.