Struct static_analyser::codemap::Span
[−]
[src]
pub struct Span(_);
A unique identifier pointing to a substring in some file.
To get back the original string this points to you'll need to look it up
in a CodeMap or FileMap.