Enum static_analyser::errors::ErrorKind
[−]
pub enum ErrorKind {
Msg(String),
Io(Error),
Utf8(Utf8Error),
FloatParsing(ParseFloatError),
IntParsing(ParseIntError),
UnexpectedEOF,
UnknownCharacter(char),
MessageWithLocation(usize, &'static str),
// some variants omitted
}The kind of an error.
Variants
Msg(String)A convenient variant for String.
Io(Error)Wrapper around a std::io::Error
Utf8(Utf8Error)An error parsing data as UTF-8
FloatParsing(ParseFloatError)A float parsing error
IntParsing(ParseIntError)An integer parsing error
UnexpectedEOFGot to the end of the input stream but was expecting more.
UnknownCharacter(char)Reached an unknown character while lexing.
MessageWithLocation(usize, &'static str)A message which corresponds to some location in the source code.
Methods
impl ErrorKind
fn description(&self) -> &str
A string describing the error kind.