Struct static_analyser::lex::Token
[−]
[src]
pub struct Token {
pub span: Span,
pub kind: TokenKind,
}A valid Delphi source code token.
Fields
span: Span
The token's location relative to the rest of the files being processed.
kind: TokenKind
What kind of token is this?
Methods
impl Token[src]
fn new<K: Into<TokenKind>>(span: Span, kind: K) -> Token
Create a new token out of a Span and something which can be turned
into a TokenKind.