Struct static_analyser::Driver
[−]
[src]
pub struct Driver { /* fields omitted */ }The driver is in charge of orchestrating the whole analysis process and making sure all the bits and pieces integrate nicely.
Methods
impl Driver[src]
fn new() -> Driver
Create a new driver.
fn codemap(&mut self) -> &mut CodeMap
Get access to the driver's CodeMap.